@@ -68,7 +68,7 @@ def detect_threshold(data, snr, background=None, error=None, mask=None,
         The number of standard deviations to use as the clipping limit
         when calculating the image background statistics.
 
-    sigclip_iters : float, optional
+    sigclip_iters : int, optional
        The number of iterations to perform sigma clipping, or `None` to
        clip until convergence is achieved (i.e., continue until the last
        iteration clips nothing) when calculating the image background
@@ -295,8 +295,11 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     data : array_like
         The 2D array of the image.
 
-    threshold : float
-        The data value to be used for the detection threshold.
+    threshold : float or array-like
+        The data value or pixel-wise data values to be used for the
+        detection threshold.  A 2D ``threshold`` must have the same
+        shape as ``data``.  See `detect_threshold` for one way to create
+        a ``threshold`` image.
 
     box_size : scalar or tuple, optional
         The size of the local region to search for peaks at every point
