@@ -40,20 +40,7 @@ class SegmentationImage(object):
 
     def __init__(self, data):
 
-        if np.min(data) < 0:
-            raise ValueError('The segmentation image cannot contain '
-                             'negative integers.')
-        self._data = np.asanyarray(data, dtype=np.int)
-        self._update_slices()
-
-    def _update_slices(self):
-        """
-        Update the segmentation slices after changes to self._data made
-        by the class methods.
-        """
-
-        from scipy.ndimage import find_objects
-        self.slices = find_objects(self._data)
+        self.data = np.asanyarray(data, dtype=np.int)
 
     @property
     def data(self):
@@ -63,6 +50,16 @@ class SegmentationImage(object):
 
         return self._data
 
+    @data.setter
+    def data(self, value):
+        if np.min(value) < 0:
+            raise ValueError('The segmentation image cannot contain '
+                             'negative integers.')
+        self._data = value
+        # be sure to delete any lazy properties to reset their values.
+        del (self.data_masked, self.shape, self.labels, self.nlabels,
+             self.max, self.slices, self.is_sequential)
+
     @property
     def array(self):
         """
@@ -79,7 +76,7 @@ class SegmentationImage(object):
 
         return self._data
 
-    @property
+    @lazyproperty
     def data_masked(self):
         """
         A `~numpy.ma.MaskedArray` version of the segmentation image
@@ -127,7 +124,7 @@ class SegmentationImage(object):
 
         return np.unique(data[data != 0])
 
-    @property
+    @lazyproperty
     def shape(self):
         """
         The shape of the 2D segmentation image.
@@ -135,25 +132,32 @@ class SegmentationImage(object):
 
         return self._data.shape
 
-    @property
+    @lazyproperty
     def labels(self):
         """The sorted non-zero labels in the segmentation image."""
 
         return self._labels(self.data)
 
-    @property
+    @lazyproperty
     def nlabels(self):
         """The number of non-zero labels in the segmentation image."""
 
         return len(self.labels)
 
-    @property
+    @lazyproperty
     def max(self):
         """The maximum non-zero label in the segmentation image."""
 
         return np.max(self.data)
 
-    @property
+    @lazyproperty
+    def slices(self):
+        """The minimal bounding box slices for each labeled region."""
+
+        from scipy.ndimage import find_objects
+        return find_objects(self._data)
+
+    @lazyproperty
     def is_sequential(self):
         """
         Determine whether or not the non-zero labels in the segmenation
@@ -186,7 +190,7 @@ class SegmentationImage(object):
         if label < 0:
             raise ValueError('label must be a positive integer, got '
                              '"{0}"'.format(label))
-        if label not in self.data:
+        if label not in self.labels:
             raise ValueError('label "{0}" is not in the segmentation '
                              'image'.format(label))
 
@@ -278,8 +282,9 @@ class SegmentationImage(object):
 
         labels = np.atleast_1d(labels)
         for label in labels:
-            self._data[np.where(self.data == label)] = new_label
-        self._update_slices()
+            data = self.data
+            data[np.where(data == label)] = new_label
+            self.data = data     # needed to call the data setter
 
     def relabel_sequential(self, start_label=1):
         """
@@ -319,8 +324,7 @@ class SegmentationImage(object):
 
         forward_map = np.zeros(self.max + 1, dtype=np.int)
         forward_map[self.labels] = np.arange(self.nlabels) + start_label
-        self._data = forward_map[self.data]
-        self._update_slices()
+        self.data = forward_map[self.data]
 
     def keep_labels(self, labels, relabel=False):
         """
